@@ -1,5 +1,5 @@
 from edam.viewer.app.views import app
-from edam.settings import SERVER
+from edam import SERVER
 
 app.jinja_env.auto_reload = True
 app.config['TEMPLATES_AUTO_RELOAD'] = True
